DeviceBuffer

Struct DeviceBuffer 

pub struct DeviceBuffer<T> { /* private fields */ }
Struct that owns a buffer allocated on GPU device. The struct only holds the raw pointer and length, but this struct has a Drop implementation which frees the associated device memory.

Implementations

Source

impl<T> DeviceBuffer<T>

pub fn new() -> Self

Creates an “empty” DeviceBuffer with a null pointer and zero length.

pub unsafe fn from_raw_parts(ptr: *mut T, len: usize) -> Self

Safety
  • The caller must ensure that the pointer ptr is valid for len elements of type T in device memory.
  • Dropping the constructed buffer will attempt to free the memory. As such, ptr must either have been allocated by the internal memory manager (VPMM) or the caller must use ManuallyDrop to prevent double-free.
pub fn with_capacity_on(len: usize, device_ctx: &GpuDeviceCtx) -> Self

Allocate device memory for len elements of type T on an explicit stream.

pub fn fill_zero_on(&self, device_ctx: &GpuDeviceCtx) -> Result<(), CudaError>

Fills the buffer with zeros on an explicit stream.

The caller should use the same stream that allocated this buffer. fill_zero is async; same-stream guarantees ordering without explicit sync.

pub fn fill_zero_suffix_on( &self, start_idx: usize, device_ctx: &GpuDeviceCtx, ) -> Result<(), CudaError>

Fills a suffix of the buffer with zeros on an explicit stream.

pub fn len(&self) -> usize

Returns the number of elements in this buffer.

pub fn is_empty(&self) -> bool

Returns whether the buffer is empty (null pointer or zero length).

pub fn as_mut_ptr(&self) -> *mut T

Returns a raw mutable pointer to the device data (typed).

pub fn as_ptr(&self) -> *const T

Returns a raw const pointer to the device data (typed).

pub fn as_mut_raw_ptr(&self) -> *mut c_void

Returns a *mut c_void (untyped) pointer.

pub fn as_raw_ptr(&self) -> *const c_void

Returns a *const c_void (untyped) pointer.

pub fn as_buffer<U>(self) -> DeviceBuffer<U>

Converts the buffer to a buffer of different type. T must be composable of Us.

pub fn view(&self) -> DeviceBufferView